<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Autostatus file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n segundos</numerusform><numerusform>%n segundos</numerusform></translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Online</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Ocupado</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisível</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>AutoStatus</source>
        <translation>Status automático</translation>
    </message>
</context>
<context>
    <name>AutostatusActions</name>
    <message>
        <source>&amp;Autostatus</source>
        <translation>&amp;Status automático</translation>
    </message>
</context>
</TS>